@@ -3,8 +3,8 @@ from PIL import ImageGrab
 
 def pil_screenshot(file_path: str = None, region: list = None):
     """
-    :param file_path save screenshot path
-    :param region screenshot region
+    :param file_path save screenshot path (None is no save)
+    :param region screenshot region (screenshot region on screen)
     """
     if region is not None:
         image = ImageGrab.grab(bbox=region)
